@@ -1,4 +1,11 @@
 
+__module_name__ = "_brownian_motion.py"
+__doc__ = """Brownian Motion Module"""
+__author__ = ", ".join(["Michael E. Vinyard"])
+__email__ = ", ".join(["vinyard@g.harvard.edu"])
+__version__ = "0.0.2"
+
+
 # -- import packages: --------------------------------------------------------------------
 import torch
 
@@ -48,4 +55,4 @@ class BrownianMotion:
         return torch.randn(self.temporal_state_shape, requires_grad=True) * self.stdev
 
     def __repr__(self):
-        return "Brownian Motion Generator"
\ No newline at end of file
+        return "Brownian Motion Generator"
